// Copyright (c) 2012 Ecma International.  All rights reserved.
// This code is governed by the BSD license found in the LICENSE file.

/*---
es5id: 15.2.3.2-2-12
description: >
    Object.getPrototypeOf returns the [[Prototype]] of its parameter
    (EvalError)
---*/

assert.sameValue(Object.getPrototypeOf(EvalError), Error, 'Object.getPrototypeOf(EvalError)');

reportCompare(0, 0);
